Learn R Programming

Rothermel (version 1.4.1)

scenarios: Moisture scenarios by Scott & Burgan (2005)

Description

A fuel Moisture Scenario is a set of fuel moisture values representing moisture condition of the surface fuel. Fuel Moisture Scenarios are useful for testing custom Fuel Models or developing fire prescriptions. For example, a moisture Scenario might be developed to represent a location's 90th-, 95th-, and 97th-percentile fire weather conditions (Andrews 2009)

Usage

data(scenarios)

Arguments

Format

A data frame with 16 observations on the following 12 variables.

Moist_1h

moisture of 1h fuel class on a dry weight basis [percent]

Moist_10h

moisture of 10h fuel class on a dry weight basis [percent]

Moist_100h

moisture of 100h fuel class on a dry weight basis [percent]

Moist_Live_Herb

moisture of herbaceous fuels on a dry weight basis [percent]

Moist_Live_Woody

moisture of woody fuels on a dry weight basis [percent]

Description

Scenario description

Examples

Run this code
data (scenarios)
barplot (as.matrix (scenarios [1, 1:5]),
        cex.names = .6,
        main = rownames (scenarios)[1])
        
# ROS using Standard fuel models and Moisture scenarios
data (scenarios, SFM_metric)
modeltype <- SFM_metric ["GR1", "Fuel_Model_Type"]
w <- SFM_metric ["GR1", 2:6]
s <- SFM_metric ["GR1", 7:11]
delta <- SFM_metric ["GR1", "Fuel_Bed_Depth"]
mx.dead <- SFM_metric ["GR1", "Mx_dead"]
h <- SFM_metric ["GR1", 14:18]
m <- scenarios ["D2L2", 1:5]
u <- 8
slope <- 0

a <- ros (modeltype, w, s, delta, mx.dead, h, m, u, slope)
a

Run the code above in your browser using DataLab